==> apache-trafficcontrol-7.0.1.tar.gz: apache-trafficcontrol-7.0.1/traffic_portal/app/src/common/modules/table/cdnFederations/TableCDNFederationsController.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

var TableCDNFederationsController = function(cdn, federations, $scope, $state, $location, locationUtils) {

	$scope.cdn = cdn;

	$scope.federations = federations;

	$scope.createFederation = function() {
		$location.path($location.path() + '/new');
	};

	$scope.editFederation = function(federation) {
		$location.path($location.path() + '/' + federation.id);
	};

	$scope.refresh = function() {
		$state.reload(); // reloads all the resolves for the view
	};

	$scope.navigateToPath = locationUtils.navigateToPath;

	angular.element(document).ready(function () {
		$('#federationsTable').dataTable({
			"aLengthMenu": [[25, 50, 100, -1], [25, 50, 100, "All"]],
			"iDisplayLength": 25,
			"aaSorting": []
		});
	});

};

TableCDNFederationsController.$inject = ['cdn', 'federations', '$scope', '$state', '$location', 'locationUtils'];
module.exports = TableCDNFederationsController;

==> apache-trafficcontrol-8.0.1.tar.gz: apache-trafficcontrol-8.0.1/traffic_portal/app/src/common/modules/table/cdnFederations/TableCDNFederationsController.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * @param {*} cdn
 * @param {*} federations
 * @param {*} $scope
 * @param {*} $state
 * @param {import("angular").ILocationService} $location
 * @param {import("../../../service/utils/LocationUtils")} locationUtils
 */
var TableCDNFederationsController = function(cdn, federations, $scope, $state, $location, locationUtils) {

	$scope.cdn = cdn;

	$scope.federations = federations;

	$scope.createFederation = function() {
		$location.path($location.path() + '/new');
	};

	$scope.editFederation = function(federation) {
		$location.path($location.path() + '/' + federation.id);
	};

	$scope.refresh = function() {
		$state.reload(); // reloads all the resolves for the view
	};

	$scope.navigateToPath = (path, unsavedChanges) => locationUtils.navigateToPath(path, unsavedChanges);

	angular.element(document).ready(function () {
		$('#federationsTable').dataTable({
			"aLengthMenu": [[25, 50, 100, -1], [25, 50, 100, "All"]],
			"iDisplayLength": 25,
			"aaSorting": []
		});
	});

};

TableCDNFederationsController.$inject = ['cdn', 'federations', '$scope', '$state', '$location', 'locationUtils'];
module.exports = TableCDNFederationsController;
